'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.request = request;

var _error = require('./error');

var _output = require('./output');

/**
 * Events of Restler
 *
 * @param {Object} r Required, restler
 * @returns {Promise}
 */
function request(r) {
  return new Promise(function (resolve, reject) {
    r.once('timeout', function (ms) {
      reject((0, _error.error)('Timeout', r.url.href, 'timeout: ' + ms + 'ms', null));
    }).once('error', function (err, response) {
      reject((0, _error.error)('Error', r.url.href, err, response));
    }).once('abort', function () {
      reject((0, _error.error)('Abort', r.url.href, null, null));
    }).once('fail', function (data, response) {
      reject((0, _error.error)('Fail', r.url.href, data, response));
    }).once('success', function (data, response) {
      resolve((0, _output.output)(data, response));
    });
  });
}